@@ -178,13 +178,13 @@ CCanvas::CCanvas()
     pushKey1->setText(tr("menu"));
     connect(pushKey1, SIGNAL(clicked()), this, SLOT(slotKey1()));
     pushKey2->setText(tr(""));
-    pushKey2->setIcon(QIcon(":/icons/menu32x32"));
+    pushKey2->setIcon(QIcon(":/icons/menu32x32.png"));
     connect(pushKey2, SIGNAL(clicked()), this, SLOT(slotKey2()));
     pushKey3->setText(tr(""));
-    pushKey3->setIcon(QIcon(":/icons/zoom-32x32"));
+    pushKey3->setIcon(QIcon(":/icons/zoom-32x32.png"));
     connect(pushKey3, SIGNAL(clicked()), this, SLOT(slotKey3()));
     pushKey4->setText(tr(""));
-    pushKey4->setIcon(QIcon(":/icons/zoom+32x32"));
+    pushKey4->setIcon(QIcon(":/icons/zoom+32x32.png"));
     connect(pushKey4, SIGNAL(clicked()), this, SLOT(slotKey4()));
 
     unit = new CUnitMetric(this);
